// Code generated by lark_sdk_gen. DO NOT EDIT.
/**
 * Copyright 2022 chyroc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package lark

import (
	"context"
)

// GetApplicationVersionList 根据 app_id 获取对应应用版本列表。
//
// doc: https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/application-v6/application-app_version/list
func (r *ApplicationService) GetApplicationVersionList(ctx context.Context, request *GetApplicationVersionListReq, options ...MethodOptionFunc) (*GetApplicationVersionListResp, *Response, error) {
	if r.cli.mock.mockApplicationGetApplicationVersionList != nil {
		r.cli.log(ctx, LogLevelDebug, "[lark] Application#GetApplicationVersionList mock enable")
		return r.cli.mock.mockApplicationGetApplicationVersionList(ctx, request, options...)
	}

	req := &RawRequestReq{
		Scope:                 "Application",
		API:                   "GetApplicationVersionList",
		Method:                "GET",
		URL:                   r.cli.openBaseURL + "/open-apis/application/v6/applications/:app_id/app_versions",
		Body:                  request,
		MethodOption:          newMethodOption(options),
		NeedTenantAccessToken: true,
	}
	resp := new(getApplicationVersionListResp)

	response, err := r.cli.RawRequest(ctx, req, resp)
	return resp.Data, response, err
}

// MockApplicationGetApplicationVersionList mock ApplicationGetApplicationVersionList method
func (r *Mock) MockApplicationGetApplicationVersionList(f func(ctx context.Context, request *GetApplicationVersionListReq, options ...MethodOptionFunc) (*GetApplicationVersionListResp, *Response, error)) {
	r.mockApplicationGetApplicationVersionList = f
}

// UnMockApplicationGetApplicationVersionList un-mock ApplicationGetApplicationVersionList method
func (r *Mock) UnMockApplicationGetApplicationVersionList() {
	r.mockApplicationGetApplicationVersionList = nil
}

// GetApplicationVersionListReq ...
type GetApplicationVersionListReq struct {
	AppID      string  `path:"app_id" json:"-"`        // 应用的 app_id, 需要查询其他应用版本信息时, 必须申请[获取应用版本信息](https://open.feishu.cn/document/ukTMukTMukTM/uQjN3QjL0YzN04CN2cDN)权限, 仅查询本应用版本信息时, 可填入 "me" 或者应用自身 app_id, 示例值: "cli_9b445f5258795107"
	Lang       string  `query:"lang" json:"-"`         // 应用信息的语言版本, 示例值: "zh_cn", 可选值有: zh_cn: 中文, en_us: 英文, ja_jp: 日文, 最小长度: `1` 字符
	PageSize   *int64  `query:"page_size" json:"-"`    // 分页大小, 示例值: 10, 默认值: `20`, 最大值: `50`
	PageToken  *string `query:"page_token" json:"-"`   // 分页标记, 第一次请求不填, 表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token, 下次遍历可采用该 page_token 获取查询结果, 示例值: "new-e3c5a0627cdf0c2e057da7257b90376a"
	Order      *int64  `query:"order" json:"-"`        // 0: 按照时间倒序 1: 按照时间正序, 示例值: 0, 默认值: `0`
	UserIDType *IDType `query:"user_id_type" json:"-"` // 用户 ID 类型, 示例值: "open_id", 可选值有: open_id: 用户的 open id, union_id: 用户的 union id, user_id: 用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 user ID
}

// GetApplicationVersionListResp ...
type GetApplicationVersionListResp struct {
	Items     []*GetApplicationVersionListRespItem `json:"items,omitempty"`      // 应用版本列表
	PageToken string                               `json:"page_token,omitempty"` // 分页标记, 当 has_more 为 true 时, 会同时返回新的 page_token, 否则不返回 page_token
	HasMore   bool                                 `json:"has_more,omitempty"`   // 是否还有更多项
}

// GetApplicationVersionListRespItem ...
type GetApplicationVersionListRespItem struct {
	AppID            string                                    `json:"app_id,omitempty"`            // 应用 id
	Version          string                                    `json:"version,omitempty"`           // 在开发者后台填入的应用版本号
	VersionID        string                                    `json:"version_id,omitempty"`        // 唯一标识应用版本的 ID
	AppName          string                                    `json:"app_name,omitempty"`          // 应用默认名称
	AvatarURL        string                                    `json:"avatar_url,omitempty"`        // 应用头像 url
	Description      string                                    `json:"description,omitempty"`       // 应用默认描述
	Scopes           []*GetApplicationVersionListRespItemScope `json:"scopes,omitempty"`            // 应用权限列表
	BackHomeURL      string                                    `json:"back_home_url,omitempty"`     // 后台主页地址
	I18n             []*GetApplicationVersionListRespItemI18n  `json:"i18n,omitempty"`              // 应用的国际化信息列表
	CommonCategories []string                                  `json:"common_categories,omitempty"` // 应用分类的国际化描述
	Events           []string                                  `json:"events,omitempty"`            // 应用已订阅开放平台事件列表
	Status           int64                                     `json:"status,omitempty"`            // 版本状态, 可选值有: 0: 未知状态, 1: 审核通过, 2: 审核拒绝, 3: 审核中, 4: 未提交审核
	CreateTime       string                                    `json:"create_time,omitempty"`       // 版本创建时间（单位: s）
	PublishTime      string                                    `json:"publish_time,omitempty"`      // 版本发布时间（单位: s）
	Ability          *GetApplicationVersionListRespItemAbility `json:"ability,omitempty"`           // 当前版本下应用开启的能力
	Remark           *GetApplicationVersionListRespItemRemark  `json:"remark,omitempty"`            // 跟随应用版本的信息
}

// GetApplicationVersionListRespItemAbility ...
type GetApplicationVersionListRespItemAbility struct {
	Gadget           *GetApplicationVersionListRespItemAbilityGadget            `json:"gadget,omitempty"`            // 小程序能力
	WebApp           *GetApplicationVersionListRespItemAbilityWebApp            `json:"web_app,omitempty"`           // 网页能力
	Bot              *GetApplicationVersionListRespItemAbilityBot               `json:"bot,omitempty"`               // 机器人能力
	WorkplaceWidgets []*GetApplicationVersionListRespItemAbilityWorkplaceWidget `json:"workplace_widgets,omitempty"` // 小组件能力
	Navigate         *GetApplicationVersionListRespItemAbilityNavigate          `json:"navigate,omitempty"`          // 主导航小程序
	CloudDoc         *GetApplicationVersionListRespItemAbilityCloudDoc          `json:"cloud_doc,omitempty"`         // 云文档应用
	DocsBlocks       []*GetApplicationVersionListRespItemAbilityDocsBlock       `json:"docs_blocks,omitempty"`       // 云文档小组件
	MessageAction    *GetApplicationVersionListRespItemAbilityMessageAction     `json:"message_action,omitempty"`    // 消息快捷操作
	PlusMenu         *GetApplicationVersionListRespItemAbilityPlusMenu          `json:"plus_menu,omitempty"`         // 加号菜单
}

// GetApplicationVersionListRespItemAbilityBot ...
type GetApplicationVersionListRespItemAbilityBot struct {
	CardRequestURL string `json:"card_request_url,omitempty"` // 消息卡片回调地址
}

// GetApplicationVersionListRespItemAbilityCloudDoc ...
type GetApplicationVersionListRespItemAbilityCloudDoc struct {
	SpaceURL string                                                  `json:"space_url,omitempty"` // 云空间重定向 url
	I18n     []*GetApplicationVersionListRespItemAbilityCloudDocI18n `json:"i18n,omitempty"`      // 国际化信息
	IconURL  string                                                  `json:"icon_url,omitempty"`  // 图标链接
	Mode     int64                                                   `json:"mode,omitempty"`      // 云文档支持模式, 可选值有: 0: 未知, 1: 移动端
}

// GetApplicationVersionListRespItemAbilityCloudDocI18n ...
type GetApplicationVersionListRespItemAbilityCloudDocI18n struct {
	I18nKey          string `json:"i18n_key,omitempty"`          // 国际化语言的 key, 可选值有: zh_cn: 中文, en_us: 英文, ja_jp: 日文
	Name             string `json:"name,omitempty"`              // 云文档国际化名称
	ReadDescription  string `json:"read_description,omitempty"`  // 云文档国际化读权限说明
	WriteDescription string `json:"write_description,omitempty"` // 云文档国际化写权限说明
}

// GetApplicationVersionListRespItemAbilityDocsBlock ...
type GetApplicationVersionListRespItemAbilityDocsBlock struct {
	BlockTypeID   string                                                   `json:"block_type_id,omitempty"`   // BlockTypeID
	I18n          []*GetApplicationVersionListRespItemAbilityDocsBlockI18n `json:"i18n,omitempty"`            // block 的国际化信息
	MobileIconURL string                                                   `json:"mobile_icon_url,omitempty"` // 移动端 icon 链接
	PcIconURL     string                                                   `json:"pc_icon_url,omitempty"`     // pc 端口 icon 链接
}

// GetApplicationVersionListRespItemAbilityDocsBlockI18n ...
type GetApplicationVersionListRespItemAbilityDocsBlockI18n struct {
	I18nKey string `json:"i18n_key,omitempty"` // 国际化语言的 key, 可选值有: zh_cn: 中文, en_us: 英文, ja_jp: 日文
	Name    string `json:"name,omitempty"`     // 名称
}

// GetApplicationVersionListRespItemAbilityGadget ...
type GetApplicationVersionListRespItemAbilityGadget struct {
	EnablePcMode         int64    `json:"enable_pc_mode,omitempty"`          // pc 支持的小程序模式, bit 位表示, 可选值有: 1: sidebar 模式, 2: pc 模式, 4: 主导航模式
	SchemaURLs           []string `json:"schema_urls,omitempty"`             // schema url 列表
	PcUseMobilePkg       bool     `json:"pc_use_mobile_pkg,omitempty"`       // pc 端是否使用小程序版本
	PcVersion            string   `json:"pc_version,omitempty"`              // pc 的小程序版本号
	MobileVersion        string   `json:"mobile_version,omitempty"`          // 移动端小程序版本号
	MobileMinLarkVersion string   `json:"mobile_min_lark_version,omitempty"` // 移动端兼容的最低飞书版本
	PcMinLarkVersion     string   `json:"pc_min_lark_version,omitempty"`     // pc 端兼容的最低飞书版本
}

// GetApplicationVersionListRespItemAbilityMessageAction ...
type GetApplicationVersionListRespItemAbilityMessageAction struct {
	PcAppLink     string                                                       `json:"pc_app_link,omitempty"`     // pc 端链接
	MobileAppLink string                                                       `json:"mobile_app_link,omitempty"` // 移动端链接
	I18n          []*GetApplicationVersionListRespItemAbilityMessageActionI18n `json:"i18n,omitempty"`            // 国际化信息
}

// GetApplicationVersionListRespItemAbilityMessageActionI18n ...
type GetApplicationVersionListRespItemAbilityMessageActionI18n struct {
	I18nKey string `json:"i18n_key,omitempty"` // 国际化语言的 key, 可选值有: zh_cn: 中文, en_us: 英文, ja_jp: 日文
	Name    string `json:"name,omitempty"`     // 国际化名称
}

// GetApplicationVersionListRespItemAbilityNavigate ...
type GetApplicationVersionListRespItemAbilityNavigate struct {
	Pc     *GetApplicationVersionListRespItemAbilityNavigatePc     `json:"pc,omitempty"`     // pc 端主导航信息
	Mobile *GetApplicationVersionListRespItemAbilityNavigateMobile `json:"mobile,omitempty"` // 移动端主导航信息
}

// GetApplicationVersionListRespItemAbilityNavigateMobile ...
type GetApplicationVersionListRespItemAbilityNavigateMobile struct {
	Version       string `json:"version,omitempty"`         // 主导航小程序版本号
	ImageURL      string `json:"image_url,omitempty"`       // 默认图片 url
	HoverImageURL string `json:"hover_image_url,omitempty"` // 选中态图片 url
}

// GetApplicationVersionListRespItemAbilityNavigatePc ...
type GetApplicationVersionListRespItemAbilityNavigatePc struct {
	Version       string `json:"version,omitempty"`         // 主导航小程序版本号
	ImageURL      string `json:"image_url,omitempty"`       // 默认图片 url
	HoverImageURL string `json:"hover_image_url,omitempty"` // 选中态图片 url
}

// GetApplicationVersionListRespItemAbilityPlusMenu ...
type GetApplicationVersionListRespItemAbilityPlusMenu struct {
	PcAppLink     string `json:"pc_app_link,omitempty"`     // pc 端链接
	MobileAppLink string `json:"mobile_app_link,omitempty"` // 移动端链接
}

// GetApplicationVersionListRespItemAbilityWebApp ...
type GetApplicationVersionListRespItemAbilityWebApp struct {
	PcURL     string `json:"pc_url,omitempty"`     // pc 端 url
	MobileURL string `json:"mobile_url,omitempty"` // 移动端 url
}

// GetApplicationVersionListRespItemAbilityWorkplaceWidget ...
type GetApplicationVersionListRespItemAbilityWorkplaceWidget struct {
	MinLarkVersion string `json:"min_lark_version,omitempty"` // 最低兼容飞书版本号
}

// GetApplicationVersionListRespItemI18n ...
type GetApplicationVersionListRespItemI18n struct {
	I18nKey     string `json:"i18n_key,omitempty"`    // 国际化语言的 key, 可选值有: zh_cn: 中文, en_us: 英文, ja_jp: 日文
	Name        string `json:"name,omitempty"`        // 应用国际化名称
	Description string `json:"description,omitempty"` // 应用国际化描述（副标题）
	HelpUse     string `json:"help_use,omitempty"`    // 帮助国际化文档链接
}

// GetApplicationVersionListRespItemRemark ...
type GetApplicationVersionListRespItemRemark struct {
	Remark       string                                             `json:"remark,omitempty"`        // 备注说明
	UpdateRemark string                                             `json:"update_remark,omitempty"` // 更新说明
	Visibility   *GetApplicationVersionListRespItemRemarkVisibility `json:"visibility,omitempty"`    // 应用当前版本开发者编辑的可见性建议, 若开发者未编辑可见性建议, 则该字段无内容
}

// GetApplicationVersionListRespItemRemarkVisibility ...
type GetApplicationVersionListRespItemRemarkVisibility struct {
	IsAll         bool                                                            `json:"is_all,omitempty"`         // 是否全员可见
	VisibleList   *GetApplicationVersionListRespItemRemarkVisibilityVisibleList   `json:"visible_list,omitempty"`   // 可见名单
	InvisibleList *GetApplicationVersionListRespItemRemarkVisibilityInvisibleList `json:"invisible_list,omitempty"` // 不可见名单
}

// GetApplicationVersionListRespItemRemarkVisibilityInvisibleList ...
type GetApplicationVersionListRespItemRemarkVisibilityInvisibleList struct {
	OpenIDs       []string `json:"open_ids,omitempty"`       // 可见性成员 open_id 列表
	DepartmentIDs []string `json:"department_ids,omitempty"` // 可见性部门的 id 列表
}

// GetApplicationVersionListRespItemRemarkVisibilityVisibleList ...
type GetApplicationVersionListRespItemRemarkVisibilityVisibleList struct {
	OpenIDs       []string `json:"open_ids,omitempty"`       // 可见性成员 open_id 列表
	DepartmentIDs []string `json:"department_ids,omitempty"` // 可见性部门的 id 列表
}

// GetApplicationVersionListRespItemScope ...
type GetApplicationVersionListRespItemScope struct {
	Scope       string `json:"scope,omitempty"`       // 应用权限
	Description string `json:"description,omitempty"` // 应用权限的国际化描述
	Level       int64  `json:"level,omitempty"`       // 权限等级描述, 可选值有: 1: 普通权限, 2: 高级权限, 3: 超敏感权限, 0: 未知等级
}

// getApplicationVersionListResp ...
type getApplicationVersionListResp struct {
	Code int64                          `json:"code,omitempty"` // 错误码, 非 0 表示失败
	Msg  string                         `json:"msg,omitempty"`  // 错误描述
	Data *GetApplicationVersionListResp `json:"data,omitempty"`
}
