// Code generated by lark_sdk_gen. DO NOT EDIT.
/**
 * Copyright 2022 chyroc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package lark

import (
	"context"
)

// BatchGetOKR 根据OKR id批量获取OKR
//
// 使用tenant_access_token需要额外申请权限以应用身份访问OKR信息
//
// doc: https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/okr-v1/okr/batch_get
func (r *OKRService) BatchGetOKR(ctx context.Context, request *BatchGetOKRReq, options ...MethodOptionFunc) (*BatchGetOKRResp, *Response, error) {
	if r.cli.mock.mockOKRBatchGetOKR != nil {
		r.cli.log(ctx, LogLevelDebug, "[lark] OKR#BatchGetOKR mock enable")
		return r.cli.mock.mockOKRBatchGetOKR(ctx, request, options...)
	}

	req := &RawRequestReq{
		Scope:                 "OKR",
		API:                   "BatchGetOKR",
		Method:                "GET",
		URL:                   r.cli.openBaseURL + "/open-apis/okr/v1/okrs/batch_get",
		Body:                  request,
		MethodOption:          newMethodOption(options),
		NeedTenantAccessToken: true,
		NeedUserAccessToken:   true,
	}
	resp := new(batchGetOKRResp)

	response, err := r.cli.RawRequest(ctx, req, resp)
	return resp.Data, response, err
}

// MockOKRBatchGetOKR mock OKRBatchGetOKR method
func (r *Mock) MockOKRBatchGetOKR(f func(ctx context.Context, request *BatchGetOKRReq, options ...MethodOptionFunc) (*BatchGetOKRResp, *Response, error)) {
	r.mockOKRBatchGetOKR = f
}

// UnMockOKRBatchGetOKR un-mock OKRBatchGetOKR method
func (r *Mock) UnMockOKRBatchGetOKR() {
	r.mockOKRBatchGetOKR = nil
}

// BatchGetOKRReq ...
type BatchGetOKRReq struct {
	UserIDType *IDType  `query:"user_id_type" json:"-"` // 用户 ID 类型, 示例值: "open_id", 可选值有: open_id: 用户的 open id, union_id: 用户的 union id, user_id: 用户的 user id, people_admin_id: 以people_admin_id来识别用户, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 user ID
	OKRIDs     []string `query:"okr_ids" json:"-"`      // OKR ID 列表, 最多10个, 示例值: 7043693679567028244, 最大长度: `10`
	Lang       *string  `query:"lang" json:"-"`         // 请求OKR的语言版本（比如@的人名）, lang=en_us/zh_cn, 请求 Query中, 示例值: "zh_cn", 默认值: `zh_cn`
}

// BatchGetOKRResp ...
type BatchGetOKRResp struct {
	OKRList []*BatchGetOKRRespOKR `json:"okr_list,omitempty"` // OKR 列表
}

// BatchGetOKRRespOKR ...
type BatchGetOKRRespOKR struct {
	ID            string                         `json:"id,omitempty"`             // id
	Permission    int64                          `json:"permission,omitempty"`     // OKR的访问权限, 可选值有: 0: 此时OKR只返回id, 1: 返回OKR的其他具体字段
	PeriodID      string                         `json:"period_id,omitempty"`      // period_id
	Name          string                         `json:"name,omitempty"`           // 名称
	ObjectiveList []*BatchGetOKRRespOKRObjective `json:"objective_list,omitempty"` // Objective列表
	ConfirmStatus int64                          `json:"confirm_status,omitempty"` // OKR确认状态, 可选值有: 0: 未填写 OKR, 1: 已填写未发起确认, 2: 已发起待上级确认, 3: 上级未通过, 4: 上级已通过
}

// BatchGetOKRRespOKRObjective ...
type BatchGetOKRRespOKRObjective struct {
	ID                                 string                                          `json:"id,omitempty"`                                      // Objective ID
	Permission                         int64                                           `json:"permission,omitempty"`                              // 权限, 可选值有: 0: 此时OKR只返回id, 1: 返回OKR的其他具体字段
	Content                            string                                          `json:"content,omitempty"`                                 // Objective 内容
	ProgressReport                     string                                          `json:"progress_report,omitempty"`                         // Objective 进度记录内容
	Score                              int64                                           `json:"score,omitempty"`                                   // Objective 分数（0 - 100）
	Weight                             float64                                         `json:"weight,omitempty"`                                  // Objective的权重（0 - 100）
	ProgressRate                       *BatchGetOKRRespOKRObjectiveProgressRate        `json:"progress_rate,omitempty"`                           // Objective进度
	KrList                             []*BatchGetOKRRespOKRObjectiveKr                `json:"kr_list,omitempty"`                                 // Objective KeyResult 列表
	AlignedObjectiveList               []*BatchGetOKRRespOKRObjectiveAlignedObjective  `json:"aligned_objective_list,omitempty"`                  // 对齐到该Objective的Objective列表
	AligningObjectiveList              []*BatchGetOKRRespOKRObjectiveAligningObjective `json:"aligning_objective_list,omitempty"`                 // 该Objective对齐到的Objective列表
	ProgressRecordList                 []*BatchGetOKRRespOKRObjectiveProgressRecord    `json:"progress_record_list,omitempty"`                    // 该Objective的进度列表
	ProgressRatePercentLastUpdatedTime string                                          `json:"progress_rate_percent_last_updated_time,omitempty"` // 最后一次进度百分比更新时间 毫秒
	ProgressRateStatusLastUpdatedTime  string                                          `json:"progress_rate_status_last_updated_time,omitempty"`  // 最后一次状态更新时间 毫秒
	ProgressRecordLastUpdatedTime      string                                          `json:"progress_record_last_updated_time,omitempty"`       // 最后一次在侧边栏新增或者编辑进展的时间 毫秒
	ProgressReportLastUpdatedTime      string                                          `json:"progress_report_last_updated_time,omitempty"`       // 最后一次编辑进展记录/备注的时间 毫秒
	ScoreLastUpdatedTime               string                                          `json:"score_last_updated_time,omitempty"`                 // 最后一次打分更新时间 毫秒
	Deadline                           string                                          `json:"deadline,omitempty"`                                // 截止时间 毫秒
	MentionedUserList                  []*BatchGetOKRRespOKRObjectiveMentionedUser     `json:"mentioned_user_list,omitempty"`                     // 该Objective提到的人员列表
}

// BatchGetOKRRespOKRObjectiveAlignedObjective ...
type BatchGetOKRRespOKRObjectiveAlignedObjective struct {
	ID    string                                            `json:"id,omitempty"`     // Objective的ID
	OKRID string                                            `json:"okr_id,omitempty"` // OKR的ID
	Owner *BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner `json:"owner,omitempty"`  // 该Objective的Owner
}

// BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner ...
type BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner struct {
	OpenID string `json:"open_id,omitempty"` // 用户的 open_id
	UserID string `json:"user_id,omitempty"` // 用户的 user_id
}

// BatchGetOKRRespOKRObjectiveAligningObjective ...
type BatchGetOKRRespOKRObjectiveAligningObjective struct {
	ID    string                                             `json:"id,omitempty"`     // Objective的ID
	OKRID string                                             `json:"okr_id,omitempty"` // OKR的ID
	Owner *BatchGetOKRRespOKRObjectiveAligningObjectiveOwner `json:"owner,omitempty"`  // 该Objective的Owner
}

// BatchGetOKRRespOKRObjectiveAligningObjectiveOwner ...
type BatchGetOKRRespOKRObjectiveAligningObjectiveOwner struct {
	OpenID string `json:"open_id,omitempty"` // 用户的 open_id
	UserID string `json:"user_id,omitempty"` // 用户的 user_id
}

// BatchGetOKRRespOKRObjectiveKr ...
type BatchGetOKRRespOKRObjectiveKr struct {
	ID                                 string                                         `json:"id,omitempty"`                                      // Key Result ID
	Content                            string                                         `json:"content,omitempty"`                                 // KeyResult 内容
	Score                              int64                                          `json:"score,omitempty"`                                   // KeyResult打分（0 - 100）
	Weight                             int64                                          `json:"weight,omitempty"`                                  // KeyResult权重（0 - 100）（废弃）
	KrWeight                           float64                                        `json:"kr_weight,omitempty"`                               // KeyResult的权重（0 - 100）
	ProgressRate                       *BatchGetOKRRespOKRObjectiveKrProgressRate     `json:"progress_rate,omitempty"`                           // KR进度
	ProgressRecordList                 []*BatchGetOKRRespOKRObjectiveKrProgressRecord `json:"progress_record_list,omitempty"`                    // 该KR的进度列表
	ProgressRatePercentLastUpdatedTime string                                         `json:"progress_rate_percent_last_updated_time,omitempty"` // 最后一次进度百分比更新时间 毫秒
	ProgressRateStatusLastUpdatedTime  string                                         `json:"progress_rate_status_last_updated_time,omitempty"`  // 最后一次状态更新时间 毫秒
	ProgressRecordLastUpdatedTime      string                                         `json:"progress_record_last_updated_time,omitempty"`       // 最后一次在侧边栏新增或者编辑进展的时间 毫秒
	ProgressReportLastUpdatedTime      string                                         `json:"progress_report_last_updated_time,omitempty"`       // 最后一次编辑进展记录/备注的时间 毫秒
	ScoreLastUpdatedTime               string                                         `json:"score_last_updated_time,omitempty"`                 // 最后一次打分更新时间 毫秒
	Deadline                           string                                         `json:"deadline,omitempty"`                                // 截止时间 毫秒
	MentionedUserList                  []*BatchGetOKRRespOKRObjectiveKrMentionedUser  `json:"mentioned_user_list,omitempty"`                     // 该Objective提到的人员列表
}

// BatchGetOKRRespOKRObjectiveKrMentionedUser ...
type BatchGetOKRRespOKRObjectiveKrMentionedUser struct {
	OpenID string `json:"open_id,omitempty"` // 用户的 open_id
	UserID string `json:"user_id,omitempty"` // 用户的 user_id
}

// BatchGetOKRRespOKRObjectiveKrProgressRate ...
type BatchGetOKRRespOKRObjectiveKrProgressRate struct {
	Percent int64  `json:"percent,omitempty"` // Objective 进度百分比 >= 0
	Status  string `json:"status,omitempty"`  // Objective 进度状态, 可选值有: -1: 未更新, 0: 正常, 1: 有风险, 2: 已延期
}

// BatchGetOKRRespOKRObjectiveKrProgressRecord ...
type BatchGetOKRRespOKRObjectiveKrProgressRecord struct {
	ID string `json:"id,omitempty"` // OKR 进展记录ID
}

// BatchGetOKRRespOKRObjectiveMentionedUser ...
type BatchGetOKRRespOKRObjectiveMentionedUser struct {
	OpenID string `json:"open_id,omitempty"` // 用户的 open_id
	UserID string `json:"user_id,omitempty"` // 用户的 user_id
}

// BatchGetOKRRespOKRObjectiveProgressRate ...
type BatchGetOKRRespOKRObjectiveProgressRate struct {
	Percent int64  `json:"percent,omitempty"` // Objective 进度百分比 >= 0
	Status  string `json:"status,omitempty"`  // Objective 进度状态, 可选值有: -1: 未更新, 0: 正常, 1: 有风险, 2: 已延期
}

// BatchGetOKRRespOKRObjectiveProgressRecord ...
type BatchGetOKRRespOKRObjectiveProgressRecord struct {
	ID string `json:"id,omitempty"` // OKR 进展记录ID
}

// batchGetOKRResp ...
type batchGetOKRResp struct {
	Code int64            `json:"code,omitempty"` // 错误码, 非 0 表示失败
	Msg  string           `json:"msg,omitempty"`  // 错误描述
	Data *BatchGetOKRResp `json:"data,omitempty"`
}
